@@ -102,7 +102,7 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
         """
         Get the amount for element.
         """
-        return self._elmap.get(el, 0)
+        return self._elmap.get(smart_element_or_specie(el), 0)
 
     def __eq__(self, other):
         for el in self.elements:
@@ -179,6 +179,27 @@ class Composition (collections.Mapping, collections.Hashable, MSONable):
 
     def __iter__(self):
         return self._elmap.__iter__()
+    
+    def almost_equals(self, other, rtol = 0.1, atol = 1e-8):
+        """
+        Returns true if compositions are equal within a tolerance.
+        
+        Args:
+            other:
+                other composition to check
+            rtol:
+                relative tolerance
+            atol:
+                absolute tolerance
+        """
+        sps = set(self.elements + other.elements)
+        for sp in sps:
+            a = self[sp]
+            b = other[sp]
+            tol = atol + rtol * (abs(a) + abs(b)) / 2
+            if abs(b-a) > tol:
+                return False
+        return True
 
     @property
     def is_element(self):
